@@ -1,6 +1,6 @@
 /*
  * debversion: PostgreSQL functions for debversion type
- * Copyright © 2009  Roger Leigh <rleigh@debian.org>
+ * Copyright © 2009,2011  Roger Leigh <rleigh@debian.org>
  * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -19,13 +19,12 @@
 
 #include <apt-pkg/debversion.h>
 
-#include "conversions.h"
-
 extern "C"
 {
 #include <postgres.h>
 #include <fmgr.h>
 #include <access/hash.h>
+#include <utils/builtins.h>
 
 #ifdef PG_MODULE_MAGIC
   PG_MODULE_MAGIC;
@@ -52,8 +51,8 @@ namespace
     int32 result;
     char *lstr, *rstr;
 
-    lstr = debversion_text_to_cstring(left);
-    rstr = debversion_text_to_cstring(right);
+    lstr = text_to_cstring(left);
+    rstr = text_to_cstring(right);
 
     result = debVS.CmpVersion (lstr, rstr);
 
@@ -92,7 +91,7 @@ extern "C"
     char *str;
     Datum result;
 
-    str = debversion_text_to_cstring(txt);
+    str = text_to_cstring(txt);
 
     result = hash_any((unsigned char *) str, strlen(str));
     pfree(str);
